# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.workforce_management_api import WorkforceManagementApi


class TestWorkforceManagementApi(unittest.TestCase):
    """ WorkforceManagementApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.workforce_management_api.WorkforceManagementApi()

    def tearDown(self):
        pass

    def test_delete_longtermforecasts_forecast_id(self):
        """
        Test case for delete_longtermforecasts_forecast_id

        Delete a forecast
        """
        pass

    def test_delete_longtermforecasts_forecast_id_modifications_forecastmodification_id(self):
        """
        Test case for delete_longtermforecasts_forecast_id_modifications_forecastmodification_id

        Delete a forecast modification
        """
        pass

    def test_get_adherence(self):
        """
        Test case for get_adherence

        Get a list of UserScheduleAdherence records for the requested users
        """
        pass

    def test_get_longtermforecasts_forecast_id(self):
        """
        Test case for get_longtermforecasts_forecast_id

        Get forecast
        """
        pass

    def test_get_longtermforecasts_forecast_id_modifications(self):
        """
        Test case for get_longtermforecasts_forecast_id_modifications

        Get forecast Modifications
        """
        pass

    def test_post_longtermforecasts(self):
        """
        Test case for post_longtermforecasts

        Create a forecast
        """
        pass

    def test_post_longtermforecasts_forecast_id_modifications(self):
        """
        Test case for post_longtermforecasts_forecast_id_modifications

        Create a forecast modification
        """
        pass

    def test_post_longtermforecasts_search(self):
        """
        Test case for post_longtermforecasts_search

        Search forecasts
        """
        pass

    def test_put_longtermforecasts_forecast_id_modifications(self):
        """
        Test case for put_longtermforecasts_forecast_id_modifications

        Update a forecast modification
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Cobrowsesession(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Cobrowsesession - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'disconnect_type': 'str',
            'pcSelf': 'Address',
            'cobrowse_session_id': 'str',
            'cobrowse_role': 'str',
            'controlling': 'list[str]',
            'viewer_url': 'str',
            'provider_event_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'provider': 'str'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'disconnect_type': 'disconnectType',
            'pcSelf': 'self',
            'cobrowse_session_id': 'cobrowseSessionId',
            'cobrowse_role': 'cobrowseRole',
            'controlling': 'controlling',
            'viewer_url': 'viewerUrl',
            'provider_event_time': 'providerEventTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'provider': 'provider'
        }

        self._state = None
        self._id = None
        self._disconnect_type = None
        self._pcSelf = None
        self._cobrowse_session_id = None
        self._cobrowse_role = None
        self._controlling = None
        self._viewer_url = None
        self._provider_event_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._provider = None

    @property
    def state(self):
        """
        Gets the state of this Cobrowsesession.
        The connection state of this communication.

        :return: The state of this Cobrowsesession.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Cobrowsesession.
        The connection state of this communication.

        :param state: The state of this Cobrowsesession.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "SCHEDULED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def id(self):
        """
        Gets the id of this Cobrowsesession.
        A globally unique identifier for this communication.

        :return: The id of this Cobrowsesession.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Cobrowsesession.
        A globally unique identifier for this communication.

        :param id: The id of this Cobrowsesession.
        :type: str
        """
        
        self._id = id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Cobrowsesession.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :return: The disconnect_type of this Cobrowsesession.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Cobrowsesession.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :param disconnect_type: The disconnect_type of this Cobrowsesession.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this Cobrowsesession.
        Address and name data for a call endpoint.

        :return: The pcSelf of this Cobrowsesession.
        :rtype: Address
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this Cobrowsesession.
        Address and name data for a call endpoint.

        :param pcSelf: The pcSelf of this Cobrowsesession.
        :type: Address
        """
        
        self._pcSelf = pcSelf

    @property
    def cobrowse_session_id(self):
        """
        Gets the cobrowse_session_id of this Cobrowsesession.
        The co-browse session ID.

        :return: The cobrowse_session_id of this Cobrowsesession.
        :rtype: str
        """
        return self._cobrowse_session_id

    @cobrowse_session_id.setter
    def cobrowse_session_id(self, cobrowse_session_id):
        """
        Sets the cobrowse_session_id of this Cobrowsesession.
        The co-browse session ID.

        :param cobrowse_session_id: The cobrowse_session_id of this Cobrowsesession.
        :type: str
        """
        
        self._cobrowse_session_id = cobrowse_session_id

    @property
    def cobrowse_role(self):
        """
        Gets the cobrowse_role of this Cobrowsesession.
        This value identifies the role of the co-browse client within the co-browse session (a client is a sharer or a viewer).

        :return: The cobrowse_role of this Cobrowsesession.
        :rtype: str
        """
        return self._cobrowse_role

    @cobrowse_role.setter
    def cobrowse_role(self, cobrowse_role):
        """
        Sets the cobrowse_role of this Cobrowsesession.
        This value identifies the role of the co-browse client within the co-browse session (a client is a sharer or a viewer).

        :param cobrowse_role: The cobrowse_role of this Cobrowsesession.
        :type: str
        """
        
        self._cobrowse_role = cobrowse_role

    @property
    def controlling(self):
        """
        Gets the controlling of this Cobrowsesession.
        ID of co-browse participants for which this client has been granted control (list is empty if this client cannot control any shared pages).

        :return: The controlling of this Cobrowsesession.
        :rtype: list[str]
        """
        return self._controlling

    @controlling.setter
    def controlling(self, controlling):
        """
        Sets the controlling of this Cobrowsesession.
        ID of co-browse participants for which this client has been granted control (list is empty if this client cannot control any shared pages).

        :param controlling: The controlling of this Cobrowsesession.
        :type: list[str]
        """
        
        self._controlling = controlling

    @property
    def viewer_url(self):
        """
        Gets the viewer_url of this Cobrowsesession.
        The URL that can be used to open co-browse session in web browser.

        :return: The viewer_url of this Cobrowsesession.
        :rtype: str
        """
        return self._viewer_url

    @viewer_url.setter
    def viewer_url(self, viewer_url):
        """
        Sets the viewer_url of this Cobrowsesession.
        The URL that can be used to open co-browse session in web browser.

        :param viewer_url: The viewer_url of this Cobrowsesession.
        :type: str
        """
        
        self._viewer_url = viewer_url

    @property
    def provider_event_time(self):
        """
        Gets the provider_event_time of this Cobrowsesession.
        The time when the provider event which triggered this conversation update happened in the corrected provider clock (milliseconds since 1970-01-01 00:00:00 UTC). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The provider_event_time of this Cobrowsesession.
        :rtype: datetime
        """
        return self._provider_event_time

    @provider_event_time.setter
    def provider_event_time(self, provider_event_time):
        """
        Sets the provider_event_time of this Cobrowsesession.
        The time when the provider event which triggered this conversation update happened in the corrected provider clock (milliseconds since 1970-01-01 00:00:00 UTC). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param provider_event_time: The provider_event_time of this Cobrowsesession.
        :type: datetime
        """
        
        self._provider_event_time = provider_event_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Cobrowsesession.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this Cobrowsesession.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Cobrowsesession.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this Cobrowsesession.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Cobrowsesession.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The disconnected_time of this Cobrowsesession.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Cobrowsesession.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param disconnected_time: The disconnected_time of this Cobrowsesession.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def provider(self):
        """
        Gets the provider of this Cobrowsesession.
        The source provider for the co-browse session.

        :return: The provider of this Cobrowsesession.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this Cobrowsesession.
        The source provider for the co-browse session.

        :param provider: The provider of this Cobrowsesession.
        :type: str
        """
        
        self._provider = provider

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationCobrowse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationCobrowse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'disconnect_type': 'str',
            'id': 'str',
            'pcSelf': 'ConversationNotificationAddress',
            'room_id': 'str',
            'cobrowse_session_id': 'str',
            'cobrowse_role': 'str',
            'controlling': 'list[str]',
            'viewer_url': 'str',
            'provider': 'str',
            'provider_event_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'disconnect_type': 'disconnectType',
            'id': 'id',
            'pcSelf': 'self',
            'room_id': 'roomId',
            'cobrowse_session_id': 'cobrowseSessionId',
            'cobrowse_role': 'cobrowseRole',
            'controlling': 'controlling',
            'viewer_url': 'viewerUrl',
            'provider': 'provider',
            'provider_event_time': 'providerEventTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._disconnect_type = None
        self._id = None
        self._pcSelf = None
        self._room_id = None
        self._cobrowse_session_id = None
        self._cobrowse_role = None
        self._controlling = None
        self._viewer_url = None
        self._provider = None
        self._provider_event_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this ConversationNotificationCobrowse.


        :return: The state of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationNotificationCobrowse.


        :param state: The state of this ConversationNotificationCobrowse.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationNotificationCobrowse.


        :return: The disconnect_type of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationNotificationCobrowse.


        :param disconnect_type: The disconnect_type of this ConversationNotificationCobrowse.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationCobrowse.


        :return: The id of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationCobrowse.


        :param id: The id of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._id = id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this ConversationNotificationCobrowse.


        :return: The pcSelf of this ConversationNotificationCobrowse.
        :rtype: ConversationNotificationAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this ConversationNotificationCobrowse.


        :param pcSelf: The pcSelf of this ConversationNotificationCobrowse.
        :type: ConversationNotificationAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def room_id(self):
        """
        Gets the room_id of this ConversationNotificationCobrowse.


        :return: The room_id of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this ConversationNotificationCobrowse.


        :param room_id: The room_id of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._room_id = room_id

    @property
    def cobrowse_session_id(self):
        """
        Gets the cobrowse_session_id of this ConversationNotificationCobrowse.


        :return: The cobrowse_session_id of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._cobrowse_session_id

    @cobrowse_session_id.setter
    def cobrowse_session_id(self, cobrowse_session_id):
        """
        Sets the cobrowse_session_id of this ConversationNotificationCobrowse.


        :param cobrowse_session_id: The cobrowse_session_id of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._cobrowse_session_id = cobrowse_session_id

    @property
    def cobrowse_role(self):
        """
        Gets the cobrowse_role of this ConversationNotificationCobrowse.


        :return: The cobrowse_role of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._cobrowse_role

    @cobrowse_role.setter
    def cobrowse_role(self, cobrowse_role):
        """
        Sets the cobrowse_role of this ConversationNotificationCobrowse.


        :param cobrowse_role: The cobrowse_role of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._cobrowse_role = cobrowse_role

    @property
    def controlling(self):
        """
        Gets the controlling of this ConversationNotificationCobrowse.


        :return: The controlling of this ConversationNotificationCobrowse.
        :rtype: list[str]
        """
        return self._controlling

    @controlling.setter
    def controlling(self, controlling):
        """
        Sets the controlling of this ConversationNotificationCobrowse.


        :param controlling: The controlling of this ConversationNotificationCobrowse.
        :type: list[str]
        """
        
        self._controlling = controlling

    @property
    def viewer_url(self):
        """
        Gets the viewer_url of this ConversationNotificationCobrowse.


        :return: The viewer_url of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._viewer_url

    @viewer_url.setter
    def viewer_url(self, viewer_url):
        """
        Sets the viewer_url of this ConversationNotificationCobrowse.


        :param viewer_url: The viewer_url of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._viewer_url = viewer_url

    @property
    def provider(self):
        """
        Gets the provider of this ConversationNotificationCobrowse.


        :return: The provider of this ConversationNotificationCobrowse.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationNotificationCobrowse.


        :param provider: The provider of this ConversationNotificationCobrowse.
        :type: str
        """
        
        self._provider = provider

    @property
    def provider_event_time(self):
        """
        Gets the provider_event_time of this ConversationNotificationCobrowse.


        :return: The provider_event_time of this ConversationNotificationCobrowse.
        :rtype: datetime
        """
        return self._provider_event_time

    @provider_event_time.setter
    def provider_event_time(self, provider_event_time):
        """
        Sets the provider_event_time of this ConversationNotificationCobrowse.


        :param provider_event_time: The provider_event_time of this ConversationNotificationCobrowse.
        :type: datetime
        """
        
        self._provider_event_time = provider_event_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationCobrowse.


        :return: The connected_time of this ConversationNotificationCobrowse.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationCobrowse.


        :param connected_time: The connected_time of this ConversationNotificationCobrowse.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationNotificationCobrowse.


        :return: The disconnected_time of this ConversationNotificationCobrowse.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationNotificationCobrowse.


        :param disconnected_time: The disconnected_time of this ConversationNotificationCobrowse.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationCobrowse.


        :return: The additional_properties of this ConversationNotificationCobrowse.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationCobrowse.


        :param additional_properties: The additional_properties of this ConversationNotificationCobrowse.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class VoicemailMessageNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailMessageNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'read': 'bool',
            'audio_recording_duration_seconds': 'int',
            'audio_recording_size_bytes': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'caller_address': 'str',
            'caller_name': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'read': 'read',
            'audio_recording_duration_seconds': 'audioRecordingDurationSeconds',
            'audio_recording_size_bytes': 'audioRecordingSizeBytes',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'caller_address': 'callerAddress',
            'caller_name': 'callerName'
        }

        self._id = None
        self._read = None
        self._audio_recording_duration_seconds = None
        self._audio_recording_size_bytes = None
        self._created_date = None
        self._modified_date = None
        self._caller_address = None
        self._caller_name = None

    @property
    def id(self):
        """
        Gets the id of this VoicemailMessageNotification.


        :return: The id of this VoicemailMessageNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoicemailMessageNotification.


        :param id: The id of this VoicemailMessageNotification.
        :type: str
        """
        
        self._id = id

    @property
    def read(self):
        """
        Gets the read of this VoicemailMessageNotification.


        :return: The read of this VoicemailMessageNotification.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this VoicemailMessageNotification.


        :param read: The read of this VoicemailMessageNotification.
        :type: bool
        """
        
        self._read = read

    @property
    def audio_recording_duration_seconds(self):
        """
        Gets the audio_recording_duration_seconds of this VoicemailMessageNotification.


        :return: The audio_recording_duration_seconds of this VoicemailMessageNotification.
        :rtype: int
        """
        return self._audio_recording_duration_seconds

    @audio_recording_duration_seconds.setter
    def audio_recording_duration_seconds(self, audio_recording_duration_seconds):
        """
        Sets the audio_recording_duration_seconds of this VoicemailMessageNotification.


        :param audio_recording_duration_seconds: The audio_recording_duration_seconds of this VoicemailMessageNotification.
        :type: int
        """
        
        self._audio_recording_duration_seconds = audio_recording_duration_seconds

    @property
    def audio_recording_size_bytes(self):
        """
        Gets the audio_recording_size_bytes of this VoicemailMessageNotification.


        :return: The audio_recording_size_bytes of this VoicemailMessageNotification.
        :rtype: int
        """
        return self._audio_recording_size_bytes

    @audio_recording_size_bytes.setter
    def audio_recording_size_bytes(self, audio_recording_size_bytes):
        """
        Sets the audio_recording_size_bytes of this VoicemailMessageNotification.


        :param audio_recording_size_bytes: The audio_recording_size_bytes of this VoicemailMessageNotification.
        :type: int
        """
        
        self._audio_recording_size_bytes = audio_recording_size_bytes

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailMessageNotification.


        :return: The created_date of this VoicemailMessageNotification.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailMessageNotification.


        :param created_date: The created_date of this VoicemailMessageNotification.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailMessageNotification.


        :return: The modified_date of this VoicemailMessageNotification.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailMessageNotification.


        :param modified_date: The modified_date of this VoicemailMessageNotification.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def caller_address(self):
        """
        Gets the caller_address of this VoicemailMessageNotification.


        :return: The caller_address of this VoicemailMessageNotification.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this VoicemailMessageNotification.


        :param caller_address: The caller_address of this VoicemailMessageNotification.
        :type: str
        """
        
        self._caller_address = caller_address

    @property
    def caller_name(self):
        """
        Gets the caller_name of this VoicemailMessageNotification.


        :return: The caller_name of this VoicemailMessageNotification.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this VoicemailMessageNotification.


        :param caller_name: The caller_name of this VoicemailMessageNotification.
        :type: str
        """
        
        self._caller_name = caller_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ForecastCreation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ForecastCreation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'number_of_periods': 'int',
            'period_frequency': 'str',
            'description': 'str',
            'metrics': 'list[str]',
            'management_unit_id': 'str'
        }

        self.attribute_map = {
            'number_of_periods': 'numberOfPeriods',
            'period_frequency': 'periodFrequency',
            'description': 'description',
            'metrics': 'metrics',
            'management_unit_id': 'managementUnitId'
        }

        self._number_of_periods = None
        self._period_frequency = None
        self._description = None
        self._metrics = None
        self._management_unit_id = None

    @property
    def number_of_periods(self):
        """
        Gets the number_of_periods of this ForecastCreation.
        The number of periods to be forecasted for

        :return: The number_of_periods of this ForecastCreation.
        :rtype: int
        """
        return self._number_of_periods

    @number_of_periods.setter
    def number_of_periods(self, number_of_periods):
        """
        Sets the number_of_periods of this ForecastCreation.
        The number of periods to be forecasted for

        :param number_of_periods: The number_of_periods of this ForecastCreation.
        :type: int
        """
        
        self._number_of_periods = number_of_periods

    @property
    def period_frequency(self):
        """
        Gets the period_frequency of this ForecastCreation.
        The frequency of the period

        :return: The period_frequency of this ForecastCreation.
        :rtype: str
        """
        return self._period_frequency

    @period_frequency.setter
    def period_frequency(self, period_frequency):
        """
        Sets the period_frequency of this ForecastCreation.
        The frequency of the period

        :param period_frequency: The period_frequency of this ForecastCreation.
        :type: str
        """
        allowed_values = ["WEEK"]
        if period_frequency not in allowed_values:
            raise ValueError(
                "Invalid value for `period_frequency`, must be one of {0}"
                .format(allowed_values)
            )

        self._period_frequency = period_frequency

    @property
    def description(self):
        """
        Gets the description of this ForecastCreation.
        The description of the forecast to be created

        :return: The description of this ForecastCreation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ForecastCreation.
        The description of the forecast to be created

        :param description: The description of this ForecastCreation.
        :type: str
        """
        
        self._description = description

    @property
    def metrics(self):
        """
        Gets the metrics of this ForecastCreation.
        The metrics the forecast is for

        :return: The metrics of this ForecastCreation.
        :rtype: list[str]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this ForecastCreation.
        The metrics the forecast is for

        :param metrics: The metrics of this ForecastCreation.
        :type: list[str]
        """
        
        self._metrics = metrics

    @property
    def management_unit_id(self):
        """
        Gets the management_unit_id of this ForecastCreation.
        The id of the management unit to which the new forecast belongs

        :return: The management_unit_id of this ForecastCreation.
        :rtype: str
        """
        return self._management_unit_id

    @management_unit_id.setter
    def management_unit_id(self, management_unit_id):
        """
        Sets the management_unit_id of this ForecastCreation.
        The id of the management unit to which the new forecast belongs

        :param management_unit_id: The management_unit_id of this ForecastCreation.
        :type: str
        """
        
        self._management_unit_id = management_unit_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class HeartBeatRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HeartBeatRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'sender_id': 'str',
            'heart_beat_timeout_in_minutes': 'int',
            'enabled': 'bool',
            'in_alarm': 'bool',
            'notification_users': 'list[User]',
            'alert_types': 'list[str]',
            'rule_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'sender_id': 'senderId',
            'heart_beat_timeout_in_minutes': 'heartBeatTimeoutInMinutes',
            'enabled': 'enabled',
            'in_alarm': 'inAlarm',
            'notification_users': 'notificationUsers',
            'alert_types': 'alertTypes',
            'rule_type': 'ruleType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._sender_id = None
        self._heart_beat_timeout_in_minutes = None
        self._enabled = False
        self._in_alarm = False
        self._notification_users = None
        self._alert_types = None
        self._rule_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this HeartBeatRule.
        The globally unique identifier for the object.

        :return: The id of this HeartBeatRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HeartBeatRule.
        The globally unique identifier for the object.

        :param id: The id of this HeartBeatRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this HeartBeatRule.
        Name of the rule

        :return: The name of this HeartBeatRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HeartBeatRule.
        Name of the rule

        :param name: The name of this HeartBeatRule.
        :type: str
        """
        
        self._name = name

    @property
    def sender_id(self):
        """
        Gets the sender_id of this HeartBeatRule.
        The value that identifies the sender of the heartbeat.

        :return: The sender_id of this HeartBeatRule.
        :rtype: str
        """
        return self._sender_id

    @sender_id.setter
    def sender_id(self, sender_id):
        """
        Sets the sender_id of this HeartBeatRule.
        The value that identifies the sender of the heartbeat.

        :param sender_id: The sender_id of this HeartBeatRule.
        :type: str
        """
        
        self._sender_id = sender_id

    @property
    def heart_beat_timeout_in_minutes(self):
        """
        Gets the heart_beat_timeout_in_minutes of this HeartBeatRule.
        The number of minutes to wait before alerting missing heartbeats.

        :return: The heart_beat_timeout_in_minutes of this HeartBeatRule.
        :rtype: int
        """
        return self._heart_beat_timeout_in_minutes

    @heart_beat_timeout_in_minutes.setter
    def heart_beat_timeout_in_minutes(self, heart_beat_timeout_in_minutes):
        """
        Sets the heart_beat_timeout_in_minutes of this HeartBeatRule.
        The number of minutes to wait before alerting missing heartbeats.

        :param heart_beat_timeout_in_minutes: The heart_beat_timeout_in_minutes of this HeartBeatRule.
        :type: int
        """
        
        self._heart_beat_timeout_in_minutes = heart_beat_timeout_in_minutes

    @property
    def enabled(self):
        """
        Gets the enabled of this HeartBeatRule.
        Indicates if the rule is enabled.

        :return: The enabled of this HeartBeatRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this HeartBeatRule.
        Indicates if the rule is enabled.

        :param enabled: The enabled of this HeartBeatRule.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def in_alarm(self):
        """
        Gets the in_alarm of this HeartBeatRule.
        Indicates if the rule is in alarm state.

        :return: The in_alarm of this HeartBeatRule.
        :rtype: bool
        """
        return self._in_alarm

    @in_alarm.setter
    def in_alarm(self, in_alarm):
        """
        Sets the in_alarm of this HeartBeatRule.
        Indicates if the rule is in alarm state.

        :param in_alarm: The in_alarm of this HeartBeatRule.
        :type: bool
        """
        
        self._in_alarm = in_alarm

    @property
    def notification_users(self):
        """
        Gets the notification_users of this HeartBeatRule.
        The ids of users who will be notified of alarm state change.

        :return: The notification_users of this HeartBeatRule.
        :rtype: list[User]
        """
        return self._notification_users

    @notification_users.setter
    def notification_users(self, notification_users):
        """
        Sets the notification_users of this HeartBeatRule.
        The ids of users who will be notified of alarm state change.

        :param notification_users: The notification_users of this HeartBeatRule.
        :type: list[User]
        """
        
        self._notification_users = notification_users

    @property
    def alert_types(self):
        """
        Gets the alert_types of this HeartBeatRule.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL'].

        :return: The alert_types of this HeartBeatRule.
        :rtype: list[str]
        """
        return self._alert_types

    @alert_types.setter
    def alert_types(self, alert_types):
        """
        Sets the alert_types of this HeartBeatRule.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL'].

        :param alert_types: The alert_types of this HeartBeatRule.
        :type: list[str]
        """
        
        self._alert_types = alert_types

    @property
    def rule_type(self):
        """
        Gets the rule_type of this HeartBeatRule.
        The type of system the will be generating the heartbeat.

        :return: The rule_type of this HeartBeatRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this HeartBeatRule.
        The type of system the will be generating the heartbeat.

        :param rule_type: The rule_type of this HeartBeatRule.
        :type: str
        """
        allowed_values = ["EDGE"]
        if rule_type not in allowed_values:
            raise ValueError(
                "Invalid value for `rule_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._rule_type = rule_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this HeartBeatRule.
        The URI for this object

        :return: The self_uri of this HeartBeatRule.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this HeartBeatRule.
        The URI for this object

        :param self_uri: The self_uri of this HeartBeatRule.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EmailAttachment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EmailAttachment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'content_path': 'str',
            'content_type': 'str',
            'attachment_id': 'str',
            'content_length': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'content_path': 'contentPath',
            'content_type': 'contentType',
            'attachment_id': 'attachmentId',
            'content_length': 'contentLength'
        }

        self._name = None
        self._content_path = None
        self._content_type = None
        self._attachment_id = None
        self._content_length = None

    @property
    def name(self):
        """
        Gets the name of this EmailAttachment.


        :return: The name of this EmailAttachment.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EmailAttachment.


        :param name: The name of this EmailAttachment.
        :type: str
        """
        
        self._name = name

    @property
    def content_path(self):
        """
        Gets the content_path of this EmailAttachment.


        :return: The content_path of this EmailAttachment.
        :rtype: str
        """
        return self._content_path

    @content_path.setter
    def content_path(self, content_path):
        """
        Sets the content_path of this EmailAttachment.


        :param content_path: The content_path of this EmailAttachment.
        :type: str
        """
        
        self._content_path = content_path

    @property
    def content_type(self):
        """
        Gets the content_type of this EmailAttachment.


        :return: The content_type of this EmailAttachment.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this EmailAttachment.


        :param content_type: The content_type of this EmailAttachment.
        :type: str
        """
        
        self._content_type = content_type

    @property
    def attachment_id(self):
        """
        Gets the attachment_id of this EmailAttachment.


        :return: The attachment_id of this EmailAttachment.
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """
        Sets the attachment_id of this EmailAttachment.


        :param attachment_id: The attachment_id of this EmailAttachment.
        :type: str
        """
        
        self._attachment_id = attachment_id

    @property
    def content_length(self):
        """
        Gets the content_length of this EmailAttachment.


        :return: The content_length of this EmailAttachment.
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """
        Sets the content_length of this EmailAttachment.


        :param content_length: The content_length of this EmailAttachment.
        :type: int
        """
        
        self._content_length = content_length

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class FieldConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FieldConfig - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'entity_type': 'str',
            'state': 'str',
            'sections': 'list[Section]',
            'version': 'str',
            'schema_version': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'entity_type': 'entityType',
            'state': 'state',
            'sections': 'sections',
            'version': 'version',
            'schema_version': 'schemaVersion',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._entity_type = None
        self._state = None
        self._sections = None
        self._version = None
        self._schema_version = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FieldConfig.
        The globally unique identifier for the object.

        :return: The id of this FieldConfig.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FieldConfig.
        The globally unique identifier for the object.

        :param id: The id of this FieldConfig.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FieldConfig.


        :return: The name of this FieldConfig.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FieldConfig.


        :param name: The name of this FieldConfig.
        :type: str
        """
        
        self._name = name

    @property
    def entity_type(self):
        """
        Gets the entity_type of this FieldConfig.


        :return: The entity_type of this FieldConfig.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this FieldConfig.


        :param entity_type: The entity_type of this FieldConfig.
        :type: str
        """
        allowed_values = ["person", "group", "org"]
        if entity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `entity_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._entity_type = entity_type

    @property
    def state(self):
        """
        Gets the state of this FieldConfig.


        :return: The state of this FieldConfig.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this FieldConfig.


        :param state: The state of this FieldConfig.
        :type: str
        """
        
        self._state = state

    @property
    def sections(self):
        """
        Gets the sections of this FieldConfig.


        :return: The sections of this FieldConfig.
        :rtype: list[Section]
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """
        Sets the sections of this FieldConfig.


        :param sections: The sections of this FieldConfig.
        :type: list[Section]
        """
        
        self._sections = sections

    @property
    def version(self):
        """
        Gets the version of this FieldConfig.


        :return: The version of this FieldConfig.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this FieldConfig.


        :param version: The version of this FieldConfig.
        :type: str
        """
        
        self._version = version

    @property
    def schema_version(self):
        """
        Gets the schema_version of this FieldConfig.


        :return: The schema_version of this FieldConfig.
        :rtype: str
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """
        Sets the schema_version of this FieldConfig.


        :param schema_version: The schema_version of this FieldConfig.
        :type: str
        """
        
        self._schema_version = schema_version

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FieldConfig.
        The URI for this object

        :return: The self_uri of this FieldConfig.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FieldConfig.
        The URI for this object

        :param self_uri: The self_uri of this FieldConfig.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ReplaceResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ReplaceResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'change_number': 'int',
            'upload_status': 'UriReference',
            'upload_destination_uri': 'str',
            'upload_method': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'change_number': 'changeNumber',
            'upload_status': 'uploadStatus',
            'upload_destination_uri': 'uploadDestinationUri',
            'upload_method': 'uploadMethod'
        }

        self._id = None
        self._name = None
        self._change_number = None
        self._upload_status = None
        self._upload_destination_uri = None
        self._upload_method = None

    @property
    def id(self):
        """
        Gets the id of this ReplaceResponse.


        :return: The id of this ReplaceResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReplaceResponse.


        :param id: The id of this ReplaceResponse.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ReplaceResponse.


        :return: The name of this ReplaceResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReplaceResponse.


        :param name: The name of this ReplaceResponse.
        :type: str
        """
        
        self._name = name

    @property
    def change_number(self):
        """
        Gets the change_number of this ReplaceResponse.


        :return: The change_number of this ReplaceResponse.
        :rtype: int
        """
        return self._change_number

    @change_number.setter
    def change_number(self, change_number):
        """
        Sets the change_number of this ReplaceResponse.


        :param change_number: The change_number of this ReplaceResponse.
        :type: int
        """
        
        self._change_number = change_number

    @property
    def upload_status(self):
        """
        Gets the upload_status of this ReplaceResponse.


        :return: The upload_status of this ReplaceResponse.
        :rtype: UriReference
        """
        return self._upload_status

    @upload_status.setter
    def upload_status(self, upload_status):
        """
        Sets the upload_status of this ReplaceResponse.


        :param upload_status: The upload_status of this ReplaceResponse.
        :type: UriReference
        """
        
        self._upload_status = upload_status

    @property
    def upload_destination_uri(self):
        """
        Gets the upload_destination_uri of this ReplaceResponse.


        :return: The upload_destination_uri of this ReplaceResponse.
        :rtype: str
        """
        return self._upload_destination_uri

    @upload_destination_uri.setter
    def upload_destination_uri(self, upload_destination_uri):
        """
        Sets the upload_destination_uri of this ReplaceResponse.


        :param upload_destination_uri: The upload_destination_uri of this ReplaceResponse.
        :type: str
        """
        
        self._upload_destination_uri = upload_destination_uri

    @property
    def upload_method(self):
        """
        Gets the upload_method of this ReplaceResponse.


        :return: The upload_method of this ReplaceResponse.
        :rtype: str
        """
        return self._upload_method

    @upload_method.setter
    def upload_method(self, upload_method):
        """
        Sets the upload_method of this ReplaceResponse.


        :param upload_method: The upload_method of this ReplaceResponse.
        :type: str
        """
        allowed_values = ["SINGLE_PUT", "MULTIPART_POST"]
        if upload_method not in allowed_values:
            raise ValueError(
                "Invalid value for `upload_method`, must be one of {0}"
                .format(allowed_values)
            )

        self._upload_method = upload_method

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class SearchAggregation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SearchAggregation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'field': 'str',
            'name': 'str',
            'type': 'str',
            'value': 'str',
            'size': 'int',
            'order': 'list[str]'
        }

        self.attribute_map = {
            'field': 'field',
            'name': 'name',
            'type': 'type',
            'value': 'value',
            'size': 'size',
            'order': 'order'
        }

        self._field = None
        self._name = None
        self._type = None
        self._value = None
        self._size = None
        self._order = None

    @property
    def field(self):
        """
        Gets the field of this SearchAggregation.
        The field used for aggregation

        :return: The field of this SearchAggregation.
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """
        Sets the field of this SearchAggregation.
        The field used for aggregation

        :param field: The field of this SearchAggregation.
        :type: str
        """
        
        self._field = field

    @property
    def name(self):
        """
        Gets the name of this SearchAggregation.
        The name of the aggregation. The response aggregation uses this name.

        :return: The name of this SearchAggregation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SearchAggregation.
        The name of the aggregation. The response aggregation uses this name.

        :param name: The name of this SearchAggregation.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this SearchAggregation.
        The type of aggregation to perform

        :return: The type of this SearchAggregation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SearchAggregation.
        The type of aggregation to perform

        :param type: The type of this SearchAggregation.
        :type: str
        """
        allowed_values = ["COUNT", "SUM", "AVERAGE", "CONTAINS", "STARTS_WITH", "ENDS_WITH"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def value(self):
        """
        Gets the value of this SearchAggregation.
        A value to use for aggregation

        :return: The value of this SearchAggregation.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SearchAggregation.
        A value to use for aggregation

        :param value: The value of this SearchAggregation.
        :type: str
        """
        
        self._value = value

    @property
    def size(self):
        """
        Gets the size of this SearchAggregation.
        The number aggregations results to return out of the entire result set

        :return: The size of this SearchAggregation.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this SearchAggregation.
        The number aggregations results to return out of the entire result set

        :param size: The size of this SearchAggregation.
        :type: int
        """
        
        self._size = size

    @property
    def order(self):
        """
        Gets the order of this SearchAggregation.
        The order in which aggregation results are sorted

        :return: The order of this SearchAggregation.
        :rtype: list[str]
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this SearchAggregation.
        The order in which aggregation results are sorted

        :param order: The order of this SearchAggregation.
        :type: list[str]
        """
        
        self._order = order

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
WorkforceManagementApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class WorkforceManagementApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_longtermforecasts_forecast_id(self, forecast_id, **kwargs):
        """
        Delete a forecast
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_longtermforecasts_forecast_id(forecast_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_longtermforecasts_forecast_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `delete_longtermforecasts_forecast_id`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_longtermforecasts_forecast_id_modifications_forecastmodification_id(self, forecast_id, forecast_modification_id, **kwargs):
        """
        Delete a forecast modification
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_longtermforecasts_forecast_id_modifications_forecastmodification_id(forecast_id, forecast_modification_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :param str forecast_modification_id: The forecast Modification id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id', 'forecast_modification_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_longtermforecasts_forecast_id_modifications_forecastmodification_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `delete_longtermforecasts_forecast_id_modifications_forecastmodification_id`")
        # verify the required parameter 'forecast_modification_id' is set
        if ('forecast_modification_id' not in params) or (params['forecast_modification_id'] is None):
            raise ValueError("Missing the required parameter `forecast_modification_id` when calling `delete_longtermforecasts_forecast_id_modifications_forecastmodification_id`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}/modifications/{forecastModificationId}'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']
        if 'forecast_modification_id' in params:
            path_params['forecastModificationId'] = params['forecast_modification_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_adherence(self, user_id, **kwargs):
        """
        Get a list of UserScheduleAdherence records for the requested users
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_adherence(user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] user_id: User Id(s) for which to fetch current schedule adherence information.  Max of 100 userIds per request (required)
        :return: UserScheduleAdherence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_adherence" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_adherence`")


        resource_path = '/api/v2/workforcemanagement/adherence'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'user_id' in params:
            query_params['userId'] = params['user_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserScheduleAdherence',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_longtermforecasts_forecast_id(self, forecast_id, **kwargs):
        """
        Get forecast
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_longtermforecasts_forecast_id(forecast_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :return: Forecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_longtermforecasts_forecast_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `get_longtermforecasts_forecast_id`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Forecast',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_longtermforecasts_forecast_id_modifications(self, forecast_id, **kwargs):
        """
        Get forecast Modifications
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_longtermforecasts_forecast_id_modifications(forecast_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :return: list[ForecastModification]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_longtermforecasts_forecast_id_modifications" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `get_longtermforecasts_forecast_id_modifications`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}/modifications'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[ForecastModification]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_longtermforecasts(self, body, **kwargs):
        """
        Create a forecast
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_longtermforecasts(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ForecastCreation body: The request body (required)
        :return: ForecastCreationCompletion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_longtermforecasts" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_longtermforecasts`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ForecastCreationCompletion',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_longtermforecasts_forecast_id_modifications(self, forecast_id, body, **kwargs):
        """
        Create a forecast modification
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_longtermforecasts_forecast_id_modifications(forecast_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :param ForecastModificationCreation body: The request body (required)
        :return: ForecastModificationCreation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_longtermforecasts_forecast_id_modifications" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `post_longtermforecasts_forecast_id_modifications`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_longtermforecasts_forecast_id_modifications`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}/modifications'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ForecastModificationCreation',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_longtermforecasts_search(self, body, **kwargs):
        """
        Search forecasts
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_longtermforecasts_search(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ForecastSearchRequest body:  (required)
        :return: ForecastMetadataEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_longtermforecasts_search" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_longtermforecasts_search`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ForecastMetadataEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_longtermforecasts_forecast_id_modifications(self, forecast_id, body, **kwargs):
        """
        Update a forecast modification
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_longtermforecasts_forecast_id_modifications(forecast_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str forecast_id: The forecast id (required)
        :param ForecastModification body: The request body (required)
        :return: ForecastModification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_longtermforecasts_forecast_id_modifications" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'forecast_id' is set
        if ('forecast_id' not in params) or (params['forecast_id'] is None):
            raise ValueError("Missing the required parameter `forecast_id` when calling `put_longtermforecasts_forecast_id_modifications`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_longtermforecasts_forecast_id_modifications`")


        resource_path = '/api/v2/workforcemanagement/longtermforecasts/{forecastId}/modifications'.replace('{format}', 'json')
        path_params = {}
        if 'forecast_id' in params:
            path_params['forecastId'] = params['forecast_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ForecastModification',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ForecastModification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ForecastModification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'forecast_id': 'str',
            'priority': 'int',
            'metric': 'str',
            'modification_type': 'str',
            'modification_value': 'float',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'attributes': 'ForecastFilterAttributes',
            'enabled': 'bool',
            'last_modified_date': 'datetime',
            'last_modified_by': 'User',
            'notes': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'forecast_id': 'forecastId',
            'priority': 'priority',
            'metric': 'metric',
            'modification_type': 'modificationType',
            'modification_value': 'modificationValue',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'attributes': 'attributes',
            'enabled': 'enabled',
            'last_modified_date': 'lastModifiedDate',
            'last_modified_by': 'lastModifiedBy',
            'notes': 'notes',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._forecast_id = None
        self._priority = None
        self._metric = None
        self._modification_type = None
        self._modification_value = None
        self._start_date = None
        self._end_date = None
        self._attributes = None
        self._enabled = False
        self._last_modified_date = None
        self._last_modified_by = None
        self._notes = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ForecastModification.
        The globally unique identifier for the object.

        :return: The id of this ForecastModification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ForecastModification.
        The globally unique identifier for the object.

        :param id: The id of this ForecastModification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ForecastModification.


        :return: The name of this ForecastModification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ForecastModification.


        :param name: The name of this ForecastModification.
        :type: str
        """
        
        self._name = name

    @property
    def forecast_id(self):
        """
        Gets the forecast_id of this ForecastModification.
        The id of the associated forecast

        :return: The forecast_id of this ForecastModification.
        :rtype: str
        """
        return self._forecast_id

    @forecast_id.setter
    def forecast_id(self, forecast_id):
        """
        Sets the forecast_id of this ForecastModification.
        The id of the associated forecast

        :param forecast_id: The forecast_id of this ForecastModification.
        :type: str
        """
        
        self._forecast_id = forecast_id

    @property
    def priority(self):
        """
        Gets the priority of this ForecastModification.
        The priority in which the modification is applied

        :return: The priority of this ForecastModification.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this ForecastModification.
        The priority in which the modification is applied

        :param priority: The priority of this ForecastModification.
        :type: int
        """
        
        self._priority = priority

    @property
    def metric(self):
        """
        Gets the metric of this ForecastModification.
        The metric the modification is appied to

        :return: The metric of this ForecastModification.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this ForecastModification.
        The metric the modification is appied to

        :param metric: The metric of this ForecastModification.
        :type: str
        """
        allowed_values = ["CALL_VOLUME", "ATT", "ACW", "CHAT_VOLUME"]
        if metric not in allowed_values:
            raise ValueError(
                "Invalid value for `metric`, must be one of {0}"
                .format(allowed_values)
            )

        self._metric = metric

    @property
    def modification_type(self):
        """
        Gets the modification_type of this ForecastModification.
        The type of modification

        :return: The modification_type of this ForecastModification.
        :rtype: str
        """
        return self._modification_type

    @modification_type.setter
    def modification_type(self, modification_type):
        """
        Sets the modification_type of this ForecastModification.
        The type of modification

        :param modification_type: The modification_type of this ForecastModification.
        :type: str
        """
        allowed_values = ["MINIMUM_PER_INTERVAL", "MAXIMUM_PER_INTERVAL", "SET_VALUE_PER_INTERVAL", "CHANGE_VALUE_PER_INTERVAL", "CHANGE_PERCENT_PER_INTERVAL", "SET_VALUE_OVER_RANGE", "CHANGE_VALUE_OVER_RANGE"]
        if modification_type not in allowed_values:
            raise ValueError(
                "Invalid value for `modification_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._modification_type = modification_type

    @property
    def modification_value(self):
        """
        Gets the modification_value of this ForecastModification.
        The value of the modification

        :return: The modification_value of this ForecastModification.
        :rtype: float
        """
        return self._modification_value

    @modification_value.setter
    def modification_value(self, modification_value):
        """
        Sets the modification_value of this ForecastModification.
        The value of the modification

        :param modification_value: The modification_value of this ForecastModification.
        :type: float
        """
        
        self._modification_value = modification_value

    @property
    def start_date(self):
        """
        Gets the start_date of this ForecastModification.
        The start of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_date of this ForecastModification.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this ForecastModification.
        The start of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_date: The start_date of this ForecastModification.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this ForecastModification.
        The end of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_date of this ForecastModification.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this ForecastModification.
        The end of the modified time period. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_date: The end_date of this ForecastModification.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def attributes(self):
        """
        Gets the attributes of this ForecastModification.
        The filters for the modification

        :return: The attributes of this ForecastModification.
        :rtype: ForecastFilterAttributes
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ForecastModification.
        The filters for the modification

        :param attributes: The attributes of this ForecastModification.
        :type: ForecastFilterAttributes
        """
        
        self._attributes = attributes

    @property
    def enabled(self):
        """
        Gets the enabled of this ForecastModification.
        Determined if the modification is currently applied

        :return: The enabled of this ForecastModification.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ForecastModification.
        Determined if the modification is currently applied

        :param enabled: The enabled of this ForecastModification.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def last_modified_date(self):
        """
        Gets the last_modified_date of this ForecastModification.
        The last time the modification was changed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_modified_date of this ForecastModification.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """
        Sets the last_modified_date of this ForecastModification.
        The last time the modification was changed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_modified_date: The last_modified_date of this ForecastModification.
        :type: datetime
        """
        
        self._last_modified_date = last_modified_date

    @property
    def last_modified_by(self):
        """
        Gets the last_modified_by of this ForecastModification.
        The last user to change the modification

        :return: The last_modified_by of this ForecastModification.
        :rtype: User
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """
        Sets the last_modified_by of this ForecastModification.
        The last user to change the modification

        :param last_modified_by: The last_modified_by of this ForecastModification.
        :type: User
        """
        
        self._last_modified_by = last_modified_by

    @property
    def notes(self):
        """
        Gets the notes of this ForecastModification.
        Any notes associated with the modification

        :return: The notes of this ForecastModification.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this ForecastModification.
        Any notes associated with the modification

        :param notes: The notes of this ForecastModification.
        :type: str
        """
        
        self._notes = notes

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ForecastModification.
        The URI for this object

        :return: The self_uri of this ForecastModification.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ForecastModification.
        The URI for this object

        :param self_uri: The self_uri of this ForecastModification.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ConversationNotificationCall(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationNotificationCall - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'error_info': 'ConversationNotificationErrorInfo',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'direction': 'str',
            'document_id': 'str',
            'pcSelf': 'ConversationNotificationSelf',
            'other': 'ConversationNotificationAddress',
            'provider': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[ConversationNotificationDisconnectReasons]',
            'fax_status': 'ConversationNotificationFaxStatus',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'direction': 'direction',
            'document_id': 'documentId',
            'pcSelf': 'self',
            'other': 'other',
            'provider': 'provider',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons',
            'fax_status': 'faxStatus',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._recording = None
        self._recording_state = None
        self._muted = None
        self._confined = None
        self._held = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._direction = None
        self._document_id = None
        self._pcSelf = None
        self._other = None
        self._provider = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None
        self._fax_status = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this ConversationNotificationCall.


        :return: The id of this ConversationNotificationCall.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationNotificationCall.


        :param id: The id of this ConversationNotificationCall.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this ConversationNotificationCall.


        :return: The state of this ConversationNotificationCall.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationNotificationCall.


        :param state: The state of this ConversationNotificationCall.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "UPLOADING", "CONVERTING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this ConversationNotificationCall.


        :return: The recording of this ConversationNotificationCall.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this ConversationNotificationCall.


        :param recording: The recording of this ConversationNotificationCall.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this ConversationNotificationCall.


        :return: The recording_state of this ConversationNotificationCall.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this ConversationNotificationCall.


        :param recording_state: The recording_state of this ConversationNotificationCall.
        :type: str
        """
        allowed_values = ["NONE", "ACTIVE", "PAUSED"]
        if recording_state not in allowed_values:
            raise ValueError(
                "Invalid value for `recording_state`, must be one of {0}"
                .format(allowed_values)
            )

        self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this ConversationNotificationCall.


        :return: The muted of this ConversationNotificationCall.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this ConversationNotificationCall.


        :param muted: The muted of this ConversationNotificationCall.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this ConversationNotificationCall.


        :return: The confined of this ConversationNotificationCall.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this ConversationNotificationCall.


        :param confined: The confined of this ConversationNotificationCall.
        :type: bool
        """
        
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this ConversationNotificationCall.


        :return: The held of this ConversationNotificationCall.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationNotificationCall.


        :param held: The held of this ConversationNotificationCall.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this ConversationNotificationCall.


        :return: The error_info of this ConversationNotificationCall.
        :rtype: ConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ConversationNotificationCall.


        :param error_info: The error_info of this ConversationNotificationCall.
        :type: ConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationNotificationCall.


        :return: The disconnect_type of this ConversationNotificationCall.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationNotificationCall.


        :param disconnect_type: The disconnect_type of this ConversationNotificationCall.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationNotificationCall.


        :return: The start_hold_time of this ConversationNotificationCall.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationNotificationCall.


        :param start_hold_time: The start_hold_time of this ConversationNotificationCall.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def direction(self):
        """
        Gets the direction of this ConversationNotificationCall.


        :return: The direction of this ConversationNotificationCall.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationNotificationCall.


        :param direction: The direction of this ConversationNotificationCall.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def document_id(self):
        """
        Gets the document_id of this ConversationNotificationCall.


        :return: The document_id of this ConversationNotificationCall.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this ConversationNotificationCall.


        :param document_id: The document_id of this ConversationNotificationCall.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this ConversationNotificationCall.


        :return: The pcSelf of this ConversationNotificationCall.
        :rtype: ConversationNotificationSelf
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this ConversationNotificationCall.


        :param pcSelf: The pcSelf of this ConversationNotificationCall.
        :type: ConversationNotificationSelf
        """
        
        self._pcSelf = pcSelf

    @property
    def other(self):
        """
        Gets the other of this ConversationNotificationCall.


        :return: The other of this ConversationNotificationCall.
        :rtype: ConversationNotificationAddress
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this ConversationNotificationCall.


        :param other: The other of this ConversationNotificationCall.
        :type: ConversationNotificationAddress
        """
        
        self._other = other

    @property
    def provider(self):
        """
        Gets the provider of this ConversationNotificationCall.


        :return: The provider of this ConversationNotificationCall.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationNotificationCall.


        :param provider: The provider of this ConversationNotificationCall.
        :type: str
        """
        
        self._provider = provider

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationNotificationCall.


        :return: The connected_time of this ConversationNotificationCall.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationNotificationCall.


        :param connected_time: The connected_time of this ConversationNotificationCall.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationNotificationCall.


        :return: The disconnected_time of this ConversationNotificationCall.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationNotificationCall.


        :param disconnected_time: The disconnected_time of this ConversationNotificationCall.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this ConversationNotificationCall.


        :return: The disconnect_reasons of this ConversationNotificationCall.
        :rtype: list[ConversationNotificationDisconnectReasons]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this ConversationNotificationCall.


        :param disconnect_reasons: The disconnect_reasons of this ConversationNotificationCall.
        :type: list[ConversationNotificationDisconnectReasons]
        """
        
        self._disconnect_reasons = disconnect_reasons

    @property
    def fax_status(self):
        """
        Gets the fax_status of this ConversationNotificationCall.


        :return: The fax_status of this ConversationNotificationCall.
        :rtype: ConversationNotificationFaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this ConversationNotificationCall.


        :param fax_status: The fax_status of this ConversationNotificationCall.
        :type: ConversationNotificationFaxStatus
        """
        
        self._fax_status = fax_status

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationNotificationCall.


        :return: The additional_properties of this ConversationNotificationCall.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationNotificationCall.


        :param additional_properties: The additional_properties of this ConversationNotificationCall.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CallConversationNotificationCallMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CallConversationNotificationCallMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'CallbackConversationNotificationUser',
            'queue': 'CallConversationNotificationUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'CallConversationNotificationErrorInfo',
            'script': 'CallConversationNotificationUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'provider': 'str',
            'external_contact': 'CallConversationNotificationUriReference',
            'external_organization': 'CallConversationNotificationUriReference',
            'muted': 'bool',
            'confined': 'bool',
            'recording': 'bool',
            'recording_state': 'str',
            'group': 'CallConversationNotificationUriReference',
            'ani': 'str',
            'dnis': 'str',
            'document_id': 'str',
            'monitored_participant_id': 'str',
            'consult_participant_id': 'str',
            'fax_status': 'CallConversationNotificationFaxStatus'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'muted': 'muted',
            'confined': 'confined',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'group': 'group',
            'ani': 'ani',
            'dnis': 'dnis',
            'document_id': 'documentId',
            'monitored_participant_id': 'monitoredParticipantId',
            'consult_participant_id': 'consultParticipantId',
            'fax_status': 'faxStatus'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._muted = None
        self._confined = None
        self._recording = None
        self._recording_state = None
        self._group = None
        self._ani = None
        self._dnis = None
        self._document_id = None
        self._monitored_participant_id = None
        self._consult_participant_id = None
        self._fax_status = None

    @property
    def id(self):
        """
        Gets the id of this CallConversationNotificationCallMediaParticipant.


        :return: The id of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CallConversationNotificationCallMediaParticipant.


        :param id: The id of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CallConversationNotificationCallMediaParticipant.


        :return: The name of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CallConversationNotificationCallMediaParticipant.


        :param name: The name of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this CallConversationNotificationCallMediaParticipant.


        :return: The address of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this CallConversationNotificationCallMediaParticipant.


        :param address: The address of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this CallConversationNotificationCallMediaParticipant.


        :return: The start_time of this CallConversationNotificationCallMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this CallConversationNotificationCallMediaParticipant.


        :param start_time: The start_time of this CallConversationNotificationCallMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this CallConversationNotificationCallMediaParticipant.


        :return: The connected_time of this CallConversationNotificationCallMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this CallConversationNotificationCallMediaParticipant.


        :param connected_time: The connected_time of this CallConversationNotificationCallMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this CallConversationNotificationCallMediaParticipant.


        :return: The end_time of this CallConversationNotificationCallMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this CallConversationNotificationCallMediaParticipant.


        :param end_time: The end_time of this CallConversationNotificationCallMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this CallConversationNotificationCallMediaParticipant.


        :return: The start_hold_time of this CallConversationNotificationCallMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this CallConversationNotificationCallMediaParticipant.


        :param start_hold_time: The start_hold_time of this CallConversationNotificationCallMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this CallConversationNotificationCallMediaParticipant.


        :return: The purpose of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this CallConversationNotificationCallMediaParticipant.


        :param purpose: The purpose of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this CallConversationNotificationCallMediaParticipant.


        :return: The state of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this CallConversationNotificationCallMediaParticipant.


        :param state: The state of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this CallConversationNotificationCallMediaParticipant.


        :return: The direction of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CallConversationNotificationCallMediaParticipant.


        :param direction: The direction of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this CallConversationNotificationCallMediaParticipant.


        :return: The disconnect_type of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this CallConversationNotificationCallMediaParticipant.


        :param disconnect_type: The disconnect_type of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this CallConversationNotificationCallMediaParticipant.


        :return: The held of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this CallConversationNotificationCallMediaParticipant.


        :param held: The held of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this CallConversationNotificationCallMediaParticipant.


        :return: The wrapup_required of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this CallConversationNotificationCallMediaParticipant.


        :param wrapup_required: The wrapup_required of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this CallConversationNotificationCallMediaParticipant.


        :return: The wrapup_prompt of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this CallConversationNotificationCallMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this CallConversationNotificationCallMediaParticipant.


        :return: The user of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallbackConversationNotificationUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CallConversationNotificationCallMediaParticipant.


        :param user: The user of this CallConversationNotificationCallMediaParticipant.
        :type: CallbackConversationNotificationUser
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this CallConversationNotificationCallMediaParticipant.


        :return: The queue of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this CallConversationNotificationCallMediaParticipant.


        :param queue: The queue of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationUriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this CallConversationNotificationCallMediaParticipant.


        :return: The attributes of this CallConversationNotificationCallMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this CallConversationNotificationCallMediaParticipant.


        :param attributes: The attributes of this CallConversationNotificationCallMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this CallConversationNotificationCallMediaParticipant.


        :return: The error_info of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this CallConversationNotificationCallMediaParticipant.


        :param error_info: The error_info of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this CallConversationNotificationCallMediaParticipant.


        :return: The script of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this CallConversationNotificationCallMediaParticipant.


        :param script: The script of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this CallConversationNotificationCallMediaParticipant.


        :return: The wrapup_timeout_ms of this CallConversationNotificationCallMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this CallConversationNotificationCallMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this CallConversationNotificationCallMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this CallConversationNotificationCallMediaParticipant.


        :return: The wrapup_skipped of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this CallConversationNotificationCallMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def provider(self):
        """
        Gets the provider of this CallConversationNotificationCallMediaParticipant.


        :return: The provider of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this CallConversationNotificationCallMediaParticipant.


        :param provider: The provider of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this CallConversationNotificationCallMediaParticipant.


        :return: The external_contact of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this CallConversationNotificationCallMediaParticipant.


        :param external_contact: The external_contact of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this CallConversationNotificationCallMediaParticipant.


        :return: The external_organization of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this CallConversationNotificationCallMediaParticipant.


        :param external_organization: The external_organization of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationUriReference
        """
        
        self._external_organization = external_organization

    @property
    def muted(self):
        """
        Gets the muted of this CallConversationNotificationCallMediaParticipant.


        :return: The muted of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this CallConversationNotificationCallMediaParticipant.


        :param muted: The muted of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this CallConversationNotificationCallMediaParticipant.


        :return: The confined of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this CallConversationNotificationCallMediaParticipant.


        :param confined: The confined of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._confined = confined

    @property
    def recording(self):
        """
        Gets the recording of this CallConversationNotificationCallMediaParticipant.


        :return: The recording of this CallConversationNotificationCallMediaParticipant.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this CallConversationNotificationCallMediaParticipant.


        :param recording: The recording of this CallConversationNotificationCallMediaParticipant.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this CallConversationNotificationCallMediaParticipant.


        :return: The recording_state of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this CallConversationNotificationCallMediaParticipant.


        :param recording_state: The recording_state of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        allowed_values = ["none", "active", "paused"]
        if recording_state not in allowed_values:
            raise ValueError(
                "Invalid value for `recording_state`, must be one of {0}"
                .format(allowed_values)
            )

        self._recording_state = recording_state

    @property
    def group(self):
        """
        Gets the group of this CallConversationNotificationCallMediaParticipant.


        :return: The group of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationUriReference
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this CallConversationNotificationCallMediaParticipant.


        :param group: The group of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationUriReference
        """
        
        self._group = group

    @property
    def ani(self):
        """
        Gets the ani of this CallConversationNotificationCallMediaParticipant.


        :return: The ani of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._ani

    @ani.setter
    def ani(self, ani):
        """
        Sets the ani of this CallConversationNotificationCallMediaParticipant.


        :param ani: The ani of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._ani = ani

    @property
    def dnis(self):
        """
        Gets the dnis of this CallConversationNotificationCallMediaParticipant.


        :return: The dnis of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._dnis

    @dnis.setter
    def dnis(self, dnis):
        """
        Sets the dnis of this CallConversationNotificationCallMediaParticipant.


        :param dnis: The dnis of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._dnis = dnis

    @property
    def document_id(self):
        """
        Gets the document_id of this CallConversationNotificationCallMediaParticipant.


        :return: The document_id of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this CallConversationNotificationCallMediaParticipant.


        :param document_id: The document_id of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def monitored_participant_id(self):
        """
        Gets the monitored_participant_id of this CallConversationNotificationCallMediaParticipant.


        :return: The monitored_participant_id of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._monitored_participant_id

    @monitored_participant_id.setter
    def monitored_participant_id(self, monitored_participant_id):
        """
        Sets the monitored_participant_id of this CallConversationNotificationCallMediaParticipant.


        :param monitored_participant_id: The monitored_participant_id of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._monitored_participant_id = monitored_participant_id

    @property
    def consult_participant_id(self):
        """
        Gets the consult_participant_id of this CallConversationNotificationCallMediaParticipant.


        :return: The consult_participant_id of this CallConversationNotificationCallMediaParticipant.
        :rtype: str
        """
        return self._consult_participant_id

    @consult_participant_id.setter
    def consult_participant_id(self, consult_participant_id):
        """
        Sets the consult_participant_id of this CallConversationNotificationCallMediaParticipant.


        :param consult_participant_id: The consult_participant_id of this CallConversationNotificationCallMediaParticipant.
        :type: str
        """
        
        self._consult_participant_id = consult_participant_id

    @property
    def fax_status(self):
        """
        Gets the fax_status of this CallConversationNotificationCallMediaParticipant.


        :return: The fax_status of this CallConversationNotificationCallMediaParticipant.
        :rtype: CallConversationNotificationFaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this CallConversationNotificationCallMediaParticipant.


        :param fax_status: The fax_status of this CallConversationNotificationCallMediaParticipant.
        :type: CallConversationNotificationFaxStatus
        """
        
        self._fax_status = fax_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Section(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Section - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'field_list': 'list[FieldList]',
            'instruction_text': 'str',
            'key': 'str',
            'state': 'str'
        }

        self.attribute_map = {
            'field_list': 'fieldList',
            'instruction_text': 'instructionText',
            'key': 'key',
            'state': 'state'
        }

        self._field_list = None
        self._instruction_text = None
        self._key = None
        self._state = None

    @property
    def field_list(self):
        """
        Gets the field_list of this Section.


        :return: The field_list of this Section.
        :rtype: list[FieldList]
        """
        return self._field_list

    @field_list.setter
    def field_list(self, field_list):
        """
        Sets the field_list of this Section.


        :param field_list: The field_list of this Section.
        :type: list[FieldList]
        """
        
        self._field_list = field_list

    @property
    def instruction_text(self):
        """
        Gets the instruction_text of this Section.


        :return: The instruction_text of this Section.
        :rtype: str
        """
        return self._instruction_text

    @instruction_text.setter
    def instruction_text(self, instruction_text):
        """
        Sets the instruction_text of this Section.


        :param instruction_text: The instruction_text of this Section.
        :type: str
        """
        
        self._instruction_text = instruction_text

    @property
    def key(self):
        """
        Gets the key of this Section.


        :return: The key of this Section.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Section.


        :param key: The key of this Section.
        :type: str
        """
        
        self._key = key

    @property
    def state(self):
        """
        Gets the state of this Section.


        :return: The state of this Section.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Section.


        :param state: The state of this Section.
        :type: str
        """
        
        self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

